In multinomineq, binary choice frequencies are represented by the number
of "hits" for each item type/condition (the vector k) and by the total
number of responses per item type/condition (the scalar or vector n).
In the multinomial format, the vector k includes all response categories
(not only the number of "hits"). This requires to define a vector options,
which indicates how many categories belong to one item type/condition (since
the total number of responses per item type is fixed).