- posterior
a vector (or matrix) with entries (or columns)
count = number of posterior samples within polytope and M =
total number of samples. See count_binom.
- prior
a vecotr or matrix similar as for posterior, but based on
samples from the prior distribution.
- exact_prior
optional: the exact prior probabability of the order constraints.
For instance, exact_prior=1/factorial(4) if pi1<pi2<pi3<pi4 (and if the prior is symmetric).
If provided, prior is ignored.
- log
whether to return the log-Bayes factor instead of the Bayes factor
- beta
prior shape parameters of the beta distributions used for approximating the
standard errors of the Bayes-factor estimates. The default is Jeffreys' prior.
- samples
number of samples from beta distributions used to compute
standard errors.
The unconstrained (encompassing) model is the saturated baseline model that assumes a separate,
independent probability for each observable frequency. The Bayes factor is obtained
as the ratio of posterior/prior samples within an order-constrained subset of the
parameter space.
The standard error of the (stepwise) encompassing Bayes factor is estimated by sampling
ratios from beta distributions, with parameters defined by the posterior/prior counts
(see Hoijtink, 2011; p. 211).