Learn R Programming

multinomineq (version 0.2.6)

stochdom_Ab: Ab-Representation for Stochastic Dominance of Histogram Bins

Description

Provides the necessary linear equality constraints to test stochastic dominance of continuous distributions, that is, whether the cumulative density functions \(F\) satisfy the constraint \(F_1(t) < F_2(t)\) for all \(t\).

Usage

stochdom_Ab(bins, conditions = 2, order = "

Arguments

bins

number of bins of histogram

conditions

number of conditions

order

order constraint on the random variables across conditions. The default order="<" implies that the random variables increase across conditions (implying that the cdfs decrease: \(F_1(t) > F_2(t)\)).

References

Heathcote, A., Brown, S., Wagenmakers, E. J., & Eidels, A. (2010). Distribution-free tests of stochastic dominance for small samples. Journal of Mathematical Psychology, 54(5), 454-463. tools:::Rd_expr_doi("10.1016/j.jmp.2010.06.005")

See Also

stochdom_bf to obtain a Bayes factor directly.

Examples

Run this code
stochdom_Ab(4, 2)
stochdom_Ab(4, 3)

Run the code above in your browser using DataLab