Learn R Programming

multinomineq (version 0.2.6)

strategy_to_Ab: Transform Pattern of Predictions to Polytope

Description

Transforms ordered item-type predictions to polytope definition. This allows to use Monte-Carlo methods to compute the Bayes factor if the number of item types is large (bf_binom).

Usage

strategy_to_Ab(strategy)

Value

a list containing the matrix A and the vector b

that define a polytope via A*x <= b.

Arguments

strategy

a decision strategy returned by strategy_multiattribute.

Details

Note: Only works for models without guessing predictions and without equality constraints (i.e., requires separate error probabilities per item type)

Examples

Run this code
# strategy:  A,B,B,A   e2

Run the code above in your browser using DataLab