Ab_multinom: Get Constraints for Product-Multinomial Probabilities
Description
Get or add inequality constraints (or vertices) to ensure that multinomial probabilities are
positive and sum to one for all choice options within each item type.
Usage
Ab_multinom(options, A = NULL, b = NULL, nonneg = FALSE)
Arguments
options
number of observable categories/probabilities for each item
type/multinomial distribution, e.g., c(3,2) for a ternary and binary item.
A
a matrix defining the convex polytope via A*x <= b.
The columns of A do not include the last choice option per item type and
thus the number of columns must be equal to sum(options-1)
(e.g., the column order of A for k = c(a1,a2,a2, b1,b2)
is c(a1,a2, b1)).
b
a vector of the same length as the number of rows of A.
nonneg
whether to add constraints that probabilities must be nonnegative
Details
If A and b are provided, the constraints are added to these inequality constraints.